/*
* file CcProxyTypePrivilege.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcProxyTypePrivilege
*
* (C) Copyright IBM Corporation 2012.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/
package com.ibm.rational.wvcm.stp.cc;

import java.util.List;

/**
 * <p>
 * A proxy type privilege provides a hierarchical mapping of ACL privilege categories and
 * their individual privileges which can be associated with a specific proxy type.
 * <p>
 * These relationships are read-only and are determined by the server.  They cannot
 * change within a given server session.
 * <p>
 * This interface provides an aggregate object for handling this data.
 * </p>
 */
public interface CcProxyTypePrivilege {

    /**
     * Get the list of privilege categories (e.g. "Read", "Change", etc.)
     * with entries in this tree.
     */
    public List<Category> getCategories();

    /**
     * 
     */
    public interface Category {
        /**
         * Get the list of privileges belonging to this category
         * (e.g. "read-info", "Delete", etc.).
         */
        public List<String> getPrivileges();
    }
}
